
# q-expansion of newform 567.2.g.l, downloaded from the LMFDB on 15 November 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 567
weight = 2
poly_data = [256, 0, -256, 0, 224, 0, -156, 0, 77, 0, -39, 0, 14, 0, -4, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, -1984, 0, 2304, 0, -872, 0, 1099, 0, -469, 0, 122, 0, -96, 0, -5], 2688], [[0, 2112, 0, -424, 0, 744, 0, -329, 0, 63, 0, -54, 0, -8, 0, -1], 448], [[2048, 0, -2064, 0, 1648, 0, -749, 0, 539, 0, -214, 0, 72, 0, -5, 0], 1344], [[0, -592, 0, 804, 0, -269, 0, 301, 0, -112, 0, 32, 0, -9, 0, -2], 672], [[592, 0, -804, 0, 269, 0, -301, 0, 112, 0, -32, 0, 9, 0, 2, 0], 336], [[0, -496, 0, 1752, 0, -1037, 0, 679, 0, -322, 0, 104, 0, -45, 0, 4], 672], [[192, 0, -160, 0, 156, 0, -77, 0, 39, 0, -14, 0, 4, 0, -1, 0], 64], [[3776, 0, -1296, 0, 1348, 0, -539, 0, 161, 0, -178, 0, 12, 0, -23, 0], 1344], [[-320, 0, 144, 0, -856, 0, 413, 0, -371, 0, 166, 0, -48, 0, 29, 0], 1344], [[0, -4736, 0, 4416, 0, -1564, 0, 791, 0, -77, 0, -38, 0, 12, 0, -37], 2688], [[0, 5632, 0, -4416, 0, 3146, 0, -2065, 0, 889, 0, -410, 0, 114, 0, -19], 1344], [[-2432, 0, -384, 0, 80, 0, -91, 0, 301, 0, -74, 0, 72, 0, -19, 0], 672], [[-4448, 0, 2808, 0, -2608, 0, 1463, 0, -665, 0, 346, 0, -96, 0, 23, 0], 672], [[0, 3392, 0, -2064, 0, 1732, 0, -1015, 0, 357, 0, -186, 0, 44, 0, -19], 896], [[0, 2656, 0, -3648, 0, 2930, 0, -1771, 0, 1015, 0, -374, 0, 138, 0, -37], 1344]]

hecke_ring_character_values = [[407, [-1, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0]], [325, [0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 1, 0, 0, 0, 0, -1], [0, 0, 0, 0, 0, -1, 0, -1, -1, 0, 0, 0, 0, 0, 0, 0], [0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0], [-1, 0, 0, 1, 0, 0, 0, 0, -1, -1, 0, 0, 0, 1, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 1, 0, 0, -1, 0], [-1, 0, 0, 1, 0, 0, 0, -2, -2, 2, 0, 0, -1, -1, 0, 0], [0, 0, -1, 0, 0, 0, -2, 0, 0, 0, 2, 0, 0, 0, 1, 1], [0, 0, 0, 0, 1, 0, 2, 0, 0, 0, 0, 1, 0, 0, 0, 0], [1, 0, 0, -1, 0, -2, 0, -1, -1, 2, 0, 0, -1, 1, 0, 0], [0, 0, 0, 0, 0, -2, 0, -1, -1, -2, 0, 0, -2, 0, 0, 0], [0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, -2, 0], [-1, 0, 0, 1, 0, 1, 0, 3, 3, 1, 0, 0, 0, -1, 0, 0], [0, -3, 0, 0, 0, 0, 0, 0, 0, 0, 1, -3, 0, 0, 1, 0], [0, -5, 0, 0, 0, 0, 0, 0, 0, 0, -1, -3, 0, 0, 0, 0], [0, -1, 0, 0, 1, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, -1], [-4, 0, 0, -2, 0, 1, 0, 0, -1, -4, 0, 0, -1, -3, 0, 0], [1, 0, 0, -1, 0, -1, 0, 4, 4, -2, 0, 0, 0, 1, 0, 0], [0, 0, -2, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1], [-4, 0, 0, 0, 0, 1, 0, 0, -2, -4, 0, 0, -1, -1, 0, 0], [4, 0, 0, 0, 0, 1, 0, 0, 0, 4, 0, 0, -1, -1, 0, 0], [0, 3, 0, 0, 2, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 3], [0, -1, 4, 0, -5, 0, 1, 0, 0, 0, 0, -5, 0, 0, 0, -1], [-2, 0, 0, 2, 0, 3, 0, -1, -1, 2, 0, 0, 1, -2, 0, 0], [0, 0, -1, 0, -5, 0, 4, 0, 0, 0, -4, 0, 0, 0, 1, 3], [9, 0, 0, -1, 0, 1, 0, 0, 0, 1, 0, 0, 3, -3, 0, 0], [0, 2, -2, 0, 1, 0, 4, 0, 0, 0, 0, 1, 0, 0, 0, 2], [3, 0, 0, -4, 0, -3, 0, 0, -2, 3, 0, 0, 3, -1, 0, 0], [0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, -4, 0, 0, 1, 0], [0, 0, 0, 1, 0, -1, 0, -5, 0, -1, 0, 0, -3, 3, 0, 0], [0, 0, -1, 0, -2, 0, 2, 0, 0, 0, -2, 0, 0, 0, 1, -5], [0, 0, -1, 0, 2, 0, 2, 0, 0, 0, -2, 0, 0, 0, 1, -3], [-2, 0, 0, 1, 0, -1, 0, 0, -5, -2, 0, 0, 1, 2, 0, 0], [0, 0, 0, 0, -1, 0, 4, 0, 0, 0, -4, 0, 0, 0, 0, 5], [-3, 0, 0, 2, 0, -2, 0, -3, 0, -2, 0, 0, 1, -1, 0, 0], [-3, 0, 0, 3, 0, 3, 0, 7, 7, 3, 0, 0, 0, -3, 0, 0], [1, 0, 0, -1, 0, -2, 0, 1, 1, -5, 0, 0, -1, 1, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 3, 0, 0, 3, 0], [0, -6, 0, 0, 0, 0, 0, 0, 0, 0, -3, -7, 0, 0, 1, 0], [0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 1, -5, 0, 0, 4, 0], [10, 0, 0, -1, 0, 1, 0, -1, 0, 1, 0, 0, 0, 0, 0, 0], [0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 2, 3, 0, 0, -4, 0], [2, 0, 0, -2, 0, -1, 0, -3, -3, 4, 0, 0, 1, 2, 0, 0], [0, 0, 2, 0, 8, 0, 1, 0, 0, 0, -1, 0, 0, 0, -2, 2], [-6, 0, 0, -1, 0, 0, 0, 0, 1, -6, 0, 0, 0, -1, 0, 0], [2, 0, 0, -2, 0, 0, 0, 0, -1, 2, 0, 0, 0, -2, 0, 0], [0, 0, 0, 0, 0, 8, 0, 7, 7, 9, 0, 0, 8, 0, 0, 0], [0, 0, 0, 0, 1, 0, -4, 0, 0, 0, 4, 0, 0, 0, 0, 1], [3, 0, 0, 5, 0, -5, 0, -6, 0, -5, 0, 0, -5, 5, 0, 0], [0, -10, 1, 0, 2, 0, -10, 0, 0, 0, 0, 2, 0, 0, 0, -10], [0, -10, 0, 0, 0, 0, 0, 0, 0, 0, 0, -3, 0, 0, -1, 0], [-9, 0, 0, 5, 0, -5, 0, 0, 0, -5, 0, 0, -5, 5, 0, 0], [0, 0, -1, 0, -4, 0, -5, 0, 0, 0, 5, 0, 0, 0, 1, -1], [0, 0, 1, 0, 3, 0, -6, 0, 0, 0, 6, 0, 0, 0, -1, 6], [0, 0, 1, 0, -2, 0, -6, 0, 0, 0, 6, 0, 0, 0, -1, -1], [0, 7, 0, 0, 0, 0, 0, 0, 0, 0, -7, 6, 0, 0, 3, 0], [-3, 0, 0, 3, 0, 2, 0, 4, 4, 9, 0, 0, -1, -3, 0, 0], [8, 0, 0, -5, 0, 5, 0, 5, 0, 5, 0, 0, 3, -3, 0, 0], [0, 11, -1, 0, 1, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 11], [3, 0, 0, -3, 0, 0, 0, 1, 1, 12, 0, 0, 3, 3, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 10, 0, 0, 0, 0], [10, 0, 0, -4, 0, 4, 0, -1, 0, 4, 0, 0, 5, -5, 0, 0], [0, -9, -2, 0, 3, 0, -2, 0, 0, 0, 0, 3, 0, 0, 0, -9], [-1, 0, 0, -1, 0, 0, 0, 0, 0, -1, 0, 0, 0, -1, 0, 0], [0, 3, 0, 0, 0, 0, 0, 0, 0, 0, -2, -3, 0, 0, -2, 0], [-4, 0, 0, -4, 0, -3, 0, 0, 3, -4, 0, 0, 3, -1, 0, 0], [4, 0, 0, -1, 0, 4, 0, 0, -4, 4, 0, 0, -4, -5, 0, 0], [0, 4, -4, 0, -9, 0, 5, 0, 0, 0, 0, -9, 0, 0, 0, 4], [3, 0, 0, -3, 0, -10, 0, -11, -11, 3, 0, 0, -7, 3, 0, 0], [0, 0, 4, 0, -5, 0, -3, 0, 0, 0, 3, 0, 0, 0, -4, 2], [0, 2, 1, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 2], [1, 0, 0, 3, 0, -3, 0, 1, 0, -3, 0, 0, -3, 3, 0, 0], [-6, 0, 0, 5, 0, -5, 0, -6, 0, -5, 0, 0, 1, -1, 0, 0], [-6, 0, 0, 4, 0, -4, 0, -2, 0, -4, 0, 0, 0, 0, 0, 0], [0, 0, 2, 0, 6, 0, 1, 0, 0, 0, -1, 0, 0, 0, -2, 4], [0, 0, 0, 0, 1, 0, 5, 0, 0, 0, -5, 0, 0, 0, 0, 10], [2, 0, 0, -2, 0, 2, 0, 11, 11, 0, 0, 0, 4, 2, 0, 0], [0, 0, 4, 0, 1, 0, -5, 0, 0, 0, 5, 0, 0, 0, -4, 3], [-1, 0, 0, 1, 0, -10, 0, -12, -12, -17, 0, 0, -11, -1, 0, 0], [0, 10, 0, 0, 0, 0, 0, 0, 0, 0, -6, 7, 0, 0, 4, 0], [-5, 0, 0, 5, 0, -1, 0, -6, -6, -6, 0, 0, -6, -5, 0, 0], [0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 5, -4, 0, 0, -2, 0], [-5, 0, 0, -4, 0, 4, 0, -4, 0, 4, 0, 0, 5, -5, 0, 0], [-11, 0, 0, 1, 0, -3, 0, 0, 1, -11, 0, 0, 3, 4, 0, 0], [0, -10, 0, 0, 0, 0, 0, 0, 0, 0, -5, 7, 0, 0, -3, 0], [0, 0, 0, 0, -6, 0, 9, 0, 0, 0, -9, 0, 0, 0, 0, -9], [21, 0, 0, -3, 0, 0, 0, 0, -7, 21, 0, 0, 0, -3, 0, 0], [0, -9, 3, 0, 3, 0, -8, 0, 0, 0, 0, 3, 0, 0, 0, -9], [0, 0, 0, 0, 0, -1, 0, 0, -4, 0, 0, 0, 1, 1, 0, 0], [0, 3, -7, 0, 10, 0, 2, 0, 0, 0, 0, 10, 0, 0, 0, 3], [0, 0, 3, 0, 6, 0, 1, 0, 0, 0, -1, 0, 0, 0, -3, 1], [-6, 0, 0, -3, 0, 2, 0, 0, -4, -6, 0, 0, -2, -5, 0, 0], [0, -2, 0, 0, 0, 0, 0, 0, 0, 0, -4, 0, 0, 0, 4, 0], [17, 0, 0, -8, 0, 8, 0, -4, 0, 8, 0, 0, 6, -6, 0, 0], [0, 0, -6, 0, -6, 0, -6, 0, 0, 0, 6, 0, 0, 0, 6, 3], [0, 0, 3, 0, 7, 0, 12, 0, 0, 0, -12, 0, 0, 0, -3, -4], [0, -3, 0, 0, 0, 0, 0, 0, 0, 0, -4, -5, 0, 0, -4, 0], [4, 0, 0, -4, 0, -11, 0, -11, -11, -5, 0, 0, -7, 4, 0, 0], [0, 0, 0, 0, 0, -9, 0, -9, -9, -19, 0, 0, -9, 0, 0, 0], [-2, 0, 0, 2, 0, -5, 0, -2, -2, -17, 0, 0, -7, -2, 0, 0], [0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 3, 2, 0, 0, 5, 0], [0, 7, 5, 0, 1, 0, 3, 0, 0, 0, 0, 1, 0, 0, 0, 7], [0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 5, -9, 0, 0, 2, 0], [-2, 0, 0, 2, 0, 0, 0, -3, -3, 24, 0, 0, -2, -2, 0, 0], [14, 0, 0, 1, 0, -3, 0, 0, -4, 14, 0, 0, 3, 4, 0, 0], [0, 6, -3, 0, -8, 0, 2, 0, 0, 0, 0, -8, 0, 0, 0, 6], [0, -11, -6, 0, 9, 0, -4, 0, 0, 0, 0, 9, 0, 0, 0, -11], [0, 1, 5, 0, -7, 0, -2, 0, 0, 0, 0, -7, 0, 0, 0, 1], [2, 0, 0, -2, 0, 8, 0, 11, 11, 12, 0, 0, 10, 2, 0, 0], [-6, 0, 0, 5, 0, -5, 0, 0, 0, -5, 0, 0, -3, 3, 0, 0], [5, 0, 0, -5, 0, 0, 0, 0, -10, 5, 0, 0, 0, -5, 0, 0], [0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 3, -3, 0, 0, -7, 0], [-7, 0, 0, -8, 0, 8, 0, 8, 0, 8, 0, 0, 10, -10, 0, 0], [-7, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, -2, 2, 0, 0], [0, 0, -1, 0, -1, 0, 5, 0, 0, 0, -5, 0, 0, 0, 1, 6], [-13, 0, 0, 2, 0, -4, 0, 0, 3, -13, 0, 0, 4, 6, 0, 0], [0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 7, -10, 0, 0, 3, 0], [0, 0, -1, 0, -3, 0, 7, 0, 0, 0, -7, 0, 0, 0, 1, 1], [0, 3, 0, 0, -4, 0, 0, 0, 0, 0, 0, -4, 0, 0, 0, 3], [-4, 0, 0, 4, 0, 1, 0, 1, 1, -7, 0, 0, -3, -4, 0, 0], [3, 0, 0, -3, 0, -1, 0, 13, 13, 0, 0, 0, 2, 3, 0, 0], [0, 5, 0, 0, 0, 0, 0, 0, 0, 0, -8, 10, 0, 0, 3, 0], [0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 8, 6, 0, 0, -3, 0], [20, 0, 0, -4, 0, 0, 0, 0, -9, 20, 0, 0, 0, -4, 0, 0], [0, 0, 8, 0, -2, 0, -3, 0, 0, 0, 3, 0, 0, 0, -8, -4], [-4, 0, 0, -6, 0, -1, 0, 0, -11, -4, 0, 0, 1, -5, 0, 0], [0, 12, 2, 0, 13, 0, 2, 0, 0, 0, 0, 13, 0, 0, 0, 12], [-3, 0, 0, 3, 0, 0, 0, -3, -3, 5, 0, 0, -3, -3, 0, 0], [-17, 0, 0, -6, 0, 6, 0, 1, 0, 6, 0, 0, 7, -7, 0, 0], [-4, 0, 0, -3, 0, 4, 0, 0, -5, -4, 0, 0, -4, -7, 0, 0], [0, 22, 0, 0, 0, 0, 0, 0, 0, 0, 12, 4, 0, 0, -2, 0], [11, 0, 0, 4, 0, -4, 0, 2, 0, -4, 0, 0, -11, 11, 0, 0], [11, 0, 0, -3, 0, 3, 0, 0, 0, 3, 0, 0, 2, -2, 0, 0], [0, 0, -2, 0, 7, 0, -11, 0, 0, 0, 11, 0, 0, 0, 2, -12], [-7, 0, 0, 5, 0, 8, 0, 0, -6, -7, 0, 0, -8, -3, 0, 0], [0, -21, 0, 0, 0, 0, 0, 0, 0, 0, -2, -3, 0, 0, -1, 0], [1, 0, 0, -1, 0, -4, 0, -8, -8, -23, 0, 0, -3, 1, 0, 0], [0, -1, 0, 0, 0, 0, 0, 0, 0, 0, -2, 13, 0, 0, 5, 0], [0, 2, 0, 0, 0, 0, 0, 0, 0, 0, -4, -1, 0, 0, -5, 0], [8, 0, 0, 6, 0, -6, 0, -12, 0, -6, 0, 0, -9, 9, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, -16, 0, 0, -2, 0], [2, 0, 0, -2, 0, 0, 0, 14, 14, -15, 0, 0, 2, 2, 0, 0], [0, 0, 1, 0, -13, 0, 3, 0, 0, 0, -3, 0, 0, 0, -1, -14], [-4, 0, 0, -7, 0, -4, 0, 0, 12, -4, 0, 0, 4, -3, 0, 0], [0, 8, 2, 0, -7, 0, 14, 0, 0, 0, 0, -7, 0, 0, 0, 8], [-3, 0, 0, 3, 0, 3, 0, -6, -6, -16, 0, 0, 0, -3, 0, 0], [0, 0, -5, 0, -2, 0, -3, 0, 0, 0, 3, 0, 0, 0, 5, 2], [0, 0, 0, -4, 0, 4, 0, 3, 0, 4, 0, 0, 6, -6, 0, 0], [0, 11, -5, 0, 5, 0, -7, 0, 0, 0, 0, 5, 0, 0, 0, 11], [-16, 0, 0, 10, 0, -10, 0, -7, 0, -10, 0, 0, -6, 6, 0, 0], [0, 0, 7, 0, -7, 0, -3, 0, 0, 0, 3, 0, 0, 0, -7, -17], [-28, 0, 0, -6, 0, 6, 0, 6, 0, 6, 0, 0, 8, -8, 0, 0], [0, 0, -12, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12, -1], [9, 0, 0, 8, 0, -8, 0, -6, 0, -8, 0, 0, -12, 12, 0, 0], [0, 0, -3, 0, 5, 0, -6, 0, 0, 0, 0, 5, 0, 0, 0, 0], [-5, 0, 0, 5, 0, 14, 0, 3, 3, -9, 0, 0, 9, -5, 0, 0], [0, 13, 0, 0, 0, 0, 0, 0, 0, 0, 12, 1, 0, 0, -1, 0], [9, 0, 0, 7, 0, -7, 0, -5, 0, -7, 0, 0, -10, 10, 0, 0], [0, 18, 4, 0, -5, 0, -1, 0, 0, 0, 0, -5, 0, 0, 0, 18], [0, -14, 0, 0, 0, 0, 0, 0, 0, 0, -3, 7, 0, 0, -1, 0], [0, 0, 2, 0, -12, 0, -4, 0, 0, 0, 4, 0, 0, 0, -2, 14], [8, 0, 0, -5, 0, -6, 0, 0, 11, 8, 0, 0, 6, 1, 0, 0], [0, -3, 5, 0, 22, 0, -7, 0, 0, 0, 0, 22, 0, 0, 0, -3], [0, 16, -7, 0, 5, 0, -2, 0, 0, 0, 0, 5, 0, 0, 0, 16], [0, 0, -12, 0, 4, 0, 5, 0, 0, 0, -5, 0, 0, 0, 12, -2], [-5, 0, 0, -9, 0, -3, 0, 0, 3, -5, 0, 0, 3, -6, 0, 0], [-22, 0, 0, -5, 0, 5, 0, 2, 0, 5, 0, 0, 1, -1, 0, 0]]
